# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   pythonProject
# FileName:      db.py
# Author:       xxxxxxx
# Datetime:     2024/1/3 18:31
# Description:
# 命名规范：文件名全小写+下划线，类名大驼峰，方法和变量小写+下划线连接，
# 常量大写，变量和常量用名词，方法用动词
# ---------------------------------------------------------------------------


'''
    数据库处理文件：
        1. 链接数据库
        2. 执行sql语句
            （1）删除语句
            （2）查询语句
        3. 关闭数据库
'''
import pymysql

from APIAutoTest_v2_my.common.read_ini import ReadIni


class DB:
    def __init__(self):
        # 创建ReadIni对象
        read_ini = ReadIni()
        # 初始化对象连接数据库
        try:
            self.conn = pymysql.connect(
                host=read_ini.get_sql_connect_message('host'),
                port=int(read_ini.get_sql_connect_message('port')),
                user=read_ini.get_sql_connect_message('user'),
                password=read_ini.get_sql_connect_message('pwd'),
                database=read_ini.get_sql_connect_message('database'),
                charset='utf8'
            )
        except:
            raise pymysql.Error('数据库连接出错！')
        else:
            # 获取数据库的游标
            self.cursor = self.conn.cursor()

    # 关闭数据库的方法
    def close(self):
        # 关闭游标
        self.cursor.close()
        # 关闭数据库
        self.conn.close()

    # 执行删除语句
    def delete(self, sql_sentence):
        # 判断sql语句是否以delete开头
        if sql_sentence.strip().lower().startswith('delete'):
            try:
                # 使用游标对象execute方法执行sql语句
                self.cursor.execute(sql_sentence)
                # 使用链接对象commit提交
                self.conn.commit()
            except:
                raise ValueError('sql语句错误')
        else:
            raise ValueError('sql语句错误')

    # 执行查询语句
    def select(self, sql_sentence):
        # 判断sql语句是否以select开头
        if sql_sentence.strip().lower().startswith('select'):
            try:
                # 使用游标对象execute方法执行sql语句
                self.cursor.execute(sql_sentence)
                # 获取执行后的结果
                select_result = self.cursor.fetchall()
                # 判断查询的结果是否为空
                # 不为空就返回第一个数据的ID
                if select_result:
                    return select_result[0][0]
            except:
                raise ValueError('sql语句错误！')
        else:
            raise ValueError('sql语句错误！')


if __name__ == '__main__':
    db = DB()
    str2 = "seleCT ID_,DEM_NAME_ FROM uc_demension limit 1"
    print(db.select(str2))