# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   pythonProject
# FileName:      read_excel.py
# Author:       xxxxxxx
# Datetime:     2024/1/3 14:38
# Description:
# 命名规范：文件名全小写+下划线，类名大驼峰，方法和变量小写+下划线连接，
# 常量大写，变量和常量用名词，方法用动词
# ---------------------------------------------------------------------------


'''读取excel并将得到的数据组成一个列表返回'''
import openpyxl

from APIAutoTest_v2_my.common.read_ini import ReadIni
from APIAutoTest_v2_my.common.read_json import read_json


class ReadExcel:
    def __init__(self,excel_path=None, table_name=None, case_data_path=None, expect_data_path=None, sql_data_path=None):
        if not(excel_path and table_name):
            # 通过ini文件获取文件路径
            self.ini = ReadIni()
            # 获取excel文件路径
            excel_path_self = self.ini.get_file_path('excel')
            #
            wb = openpyxl.load_workbook(excel_path_self)
            # 获取工作表名称
            table_name_self = self.ini.get_table_name('name')
            self.ws = wb[table_name_self]
        else:
            # 打开工作表
            self.wb = openpyxl.load_workbook(excel_path)
            # 获取工作表
            self.ws = self.wb[table_name]

        if not(case_data_path and expect_data_path and sql_data_path):
            # 获取用例数据文件路径
            case_data_path = self.ini.get_file_path('case')
            # 获取期望数据文件路径
            expect_data_path = self.ini.get_file_path('expect')
            # 获取sql数据文件路径
            sql_data_path = self.ini.get_file_path('sql')
        # 获取json数据
        self.case_data = read_json(case_data_path)
        self.expect_data = read_json(expect_data_path)
        self.sql_data = read_json(sql_data_path)

    # 根据行号列号读取格子数据，并将读取的数据返回出来，注意要做空行处理
    def __get_cell_value(self, column: str, row: int):
        try:
            # 获取值
            cell_value = self.ws[column + str(row)].value
        except:
            raise ValueError('传入的行号和列号错误')
        else:
            if cell_value is None:
                return None
            elif cell_value.strip():
                return cell_value.strip()

    # 根据行号获取模块名称
    def module_name(self, row):
        return self.__get_cell_value('B', row)

    # 根据行号获取接口名称
    def api_name(self, row):
        return self.__get_cell_value('C', row)

    # 根据行号获取请求路径
    def request_url(self, row):
        # 获取域名
        bpm_host = self.ini.get_host('bpm_host')
        if self.__get_cell_value('G', row):
            return bpm_host + self.__get_cell_value('G', row)

    # 根据行号获取请求方法
    def request_method(self, row):
        return self.__get_cell_value('F', row)

    # 根据行号获取媒体类型
    def mime(self, row):
        mime = self.__get_cell_value('H', row)
        if mime:
            return mime.lower()

    # 根据行号获取用例数据
    def get_case_data(self, row):
        # 获取用例数据名称
        case_data_name = self.__get_cell_value('I', row)
        # 如果存在获取用例数据
        if case_data_name:
            # 获取模块名称
            module_name = self.module_name(row)
            # 获取接口名称
            api_name = self.api_name(row)
            return self.case_data[module_name][api_name][case_data_name]

    # 根据行号获取期望数据
    def get_expect_data(self, row):
        # 获取用例数据名称
        case_expect_name = self.__get_cell_value('J', row)
        # 如果存在就获取期望数据，如果不存在则不获取
        if case_expect_name:
            # 获取模块名称
            module_name = self.module_name(row)
            # 获取接口名称
            api_name = self.api_name(row)
            return self.expect_data[module_name][api_name][case_expect_name]

    # 根据行号获取sql语句类型
    def get_sql_type(self, row):
        sql_type = self.__get_cell_value('K', row)
        if sql_type:
            return sql_type.lower()

    # 根据行号获取sql语句
    def get_sql_sentence(self, row):
        # 获取模块名称
        module_name = self.module_name(row)
        # 获取接口名称
        api_name = self.api_name(row)
        # 获取用例数据名称
        sql_data_name = self.__get_cell_value('L', row)
        # 如果存在就获取期望数据，如果不存在则不获取
        if sql_data_name:
            return self.sql_data[module_name][api_name][sql_data_name]

    # 根据行号获取更新的key
    def get_key(self, row):
        return self.__get_cell_value('M', row)

    # 将excel表中的数据组成一个二位列表返回
    def get_data(self):
        data_list = []
        for row in range(2, self.ws.max_row + 1):
            # 获取模块名称
            module_name = self.module_name(row)
            # 获取api接口名称
            api_name = self.api_name(row)
            # 获取请求路径
            request_url = self.request_url(row)
            # 获取请求方法
            request_method = self.request_method(row)
            # 获取媒体类型
            request_mime = self.mime(row)
            # 获取用例数据
            case_data = self.get_case_data(row)
            # 获取期望用例数据
            except_data = self.get_expect_data(row)
            # 获取sql语句类型
            sql_type = self.get_sql_type(row)
            # 获取sql语句
            sql_sentence = self.get_sql_sentence(row)
            # 获取跟新的key
            key = self.get_key(row)
            # 将上面的数据都放入一个数组当中国
            row_list = [request_url, request_method, request_mime, case_data, except_data, sql_type,sql_sentence, key]
            # 判断一下有没有超过5个的none，
            if not row_list.count(None) > 5:
                data_list.append(row_list)
        return data_list


if __name__ == '__main__':
    read_excel = ReadExcel()
    print(read_excel.get_data())
