# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   pythonProject
# FileName:      read_ini.py
# Author:       xxxxxxx
# Datetime:     2024/1/2 14:25
# Description:
# 命名规范：文件名全小写+下划线，类名大驼峰，方法和变量小写+下划线连接，
# 常量大写，变量和常量用名词，方法用动词
# ---------------------------------------------------------------------------
import configparser
import os.path

from APIAutoTest_v2_my.common import log_decorator



class ReadIni:
    @log_decorator
    def __init__(self):
        # 获取data_config的目录路径
        self.data_config_path = os.path.join(os.path.dirname(os.path.dirname(__file__)), 'data_config')
        # 获取config文件的路径
        ini_path = os.path.join(self.data_config_path, 'config.ini')
        # 创建configparser对象
        self.conf = configparser.ConfigParser()
        # 读文件
        self.conf.read(ini_path, encoding='utf-8')

    # 获取配置文件中各种key的方法
    # 获取ini文件中文件路径的方法
    @log_decorator
    def get_file_path(self, key):
        try:
            filename = os.path.join(self.data_config_path, self.conf.get('file', key))
        except:
            raise KeyError('传入的文件名称错误！')
        else:
            return filename

    # 获取配置文件中table名称的方法
    @log_decorator
    def get_table_name(self, key):
        try:
            table_name = self.conf.get('table', key)
        except:
            raise KeyError('传入的table节点下key错误！')
        else:
            return table_name

    # 获取配置文件中host的方法
    @log_decorator
    def get_host(self, key):
        try:
            host = self.conf.get('host', key)
        except:
            raise KeyError('传入的host名称错误')
        else:
            return host

    # 获取配置文件中sql的方法
    @log_decorator
    def get_sql_connect_message(self, key):
        try:
            sql = self.conf.get('sql', key)
        except:
            raise KeyError('传入的sql节点下的key错误')
        else:
            return sql


if __name__ == '__main__':
    ini = ReadIni()
    print(ini.get_sql_connect_message('database'))
