# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   pythonProject
# FileName:      requests_method.py
# Author:       xxxxxxx
# Datetime:     2024/1/3 19:17
# Description:
# 命名规范：文件名全小写+下划线，类名大驼峰，方法和变量小写+下划线连接，
# 常量大写，变量和常量用名词，方法用动词
# ---------------------------------------------------------------------------
import base64

import requests

from APIAutoTest_v2_my.common.read_ini import ReadIni


class RequestsMethod:
    def __init__(self):
        # 1. 登录BPM系统配置headers
        # 1.1 配置login的请求url
        self.read_ini = ReadIni()
        login_url = self.read_ini.get_host('bpm_host') + '/auth'
        # 1.2 配置登录数据
        login_data = {
            "password": base64.b64encode('123456'.encode()).decode(),
            "username": "admin"
        }
        # 1.3 创建session对象
        self.bpm_session = requests.sessions.Session()
        # 1.4 发送登录请求
        login_res = self.bpm_session.request(method="post", url=login_url, json=login_data)
        # 1.5 获取token并且配置到headers里面
        self.bpm_session.headers['Authorization'] = "Bearer " + login_res.json().get('token')

    def request_all(self, req_url, req_method, req_mime, req_data):
        if req_mime == 'application/x-www-form-urlencoded' or req_mime == 'x-www-form-urlencoded':
            return self.bpm_session.request(method=req_method, url=req_url, data=req_data)
        elif req_mime == 'application/json' or req_mime == 'json':
            return self.bpm_session.request(method=req_method, url=req_url, json=req_data)
        elif req_mime == 'multipart/form-data' or req_mime == 'form-data':
            return self.bpm_session.request(method=req_method, url=req_url, files=req_data)
        elif req_mime == 'query' or req_mime == 'params':
            return self.bpm_session.request(method=req_method, url=req_url, params=req_data)
        elif req_mime is None:
            return self.bpm_session.request(method=req_method, url=req_url)
        # 判断媒体类型是否为query|json或者json|query,表示地址栏和请求体同时传参
        elif req_mime == 'query|json' or req_mime == "json|query" or req_mime == "json|params" or req_mime == "params|json":
            return self.bpm_session.request(method=req_method, url=req_url, params=req_data.get("query"),
                                            json=req_data.get("json"))

        # 判断媒体类型是否为text或者为text/plain，使用data关键字传参
        elif req_mime == "text" or req_mime == "text/plain":
            return self.bpm_session.request(method=req_method, url=req_url, data=req_data)
        else:
            raise NameError('传入的媒体类型错误，请自行封装！')
